@@ -25,14 +25,13 @@ pamr.surv.to.class2 <- function (y, icens, cutoffs=NULL, n.class=NULL,  class.na
 # n.class - number of classes to create
 # class.names - optional vector of names for each class
 {
-        require(survival)
         if (is.null(cutoffs) & is.null(n.class)) {
                 stop("Must specify either cutoffs or n.class")
         }
         if (!is.null(cutoffs) & !is.null(n.class)) {
                 stop("Can't have both cutoffs and n.class specified")
         }
-        data.sfit <- survfit(Surv(y,icens))
+        data.sfit <- survfit(Surv(y,icens) ~ 1)
         if (!is.null(cutoffs)) {
                 if (is.null(class.names)) {
                         class.names <- 1:(length(cutoffs)+1)
@@ -63,7 +62,7 @@ gen.y.mat2 <- function(surv.data, cutoffs, class.names=NULL, newdata=surv.data)
 # and uses this information to calculate the probability that
 # a patient with a censored survival time died in a given interval.
 {
-         data.sfit <- survfit(surv.data)
+         data.sfit <- survfit(surv.data ~ 1)
          surv.ndx <- find.surv.ndx(cutoffs, data.sfit$time)
          surv.probs <- c(0, 1-data.sfit$surv[surv.ndx],1)
          surv.probs <- c(rep(0, sum((surv.ndx==0))), surv.probs)
@@ -128,7 +127,6 @@ kmeans2 <- function(x, ..., n.rep=10)
 # Performs k-means clustering multiple times from different starting
 # points
 {
-        require(cluster)
         wss <- Inf
         for (i in 1:n.rep) {
                 cur.fit <- kmeans(x, ...)
@@ -300,7 +298,6 @@ return(tt)
 }
 pamr.plotsurvival <- function(group, survival.time, censoring.status){
   # plots Kaplan-Meier curves stratified by "group"
-  require(survival)
   n.class <- length(unique(group))
   junk <- survfit(Surv(survival.time, censoring.status)~as.factor(group))
   junk2 <- coxph(Surv(survival.time, censoring.status) ~ as.factor(group))      
@@ -322,15 +319,13 @@ return()
                 return(1 - pchisq(loglik, ngroup.survival - 1))
         }
 order.class.survival <- function(a, survival.time, censoring.status){
-require(survival)
-
 #orders the classes specified in "a" by median survival time, from
 #shortest to longest
 
 med <- rep(NA,length(table(a)))
 for(i in 1:length(table(a))){
     o <- a==i
-    aa <- survfit(Surv(survival.time[o],censoring.status[o]))
+    aa <- survfit(Surv(survival.time[o],censoring.status[o]) ~ 1)
     med[i] <- approx(aa$surv,aa$time, xout=.5, method="constant")$y
     }
 aa <- rep(NA,length(a))
